"""
base tables
"""
from django.utils.translation import ugettext_lazy as _

from installations import models as installations_models

from utils import tables
from utils.versioning import helpers

class ScenariosTable(tables.ModelTable):
    name = tables.Column(
            verbose_name = _('Scenario'),
            link = lambda x: x.data.get_absolute_url(),
            sortable = True,
        )
    scope = tables.Column(
            verbose_name = _('Scope'),
            link = lambda x: x.data.scope.get_redirect_url(),
        )
    class Meta:
##        model = app_models.Scenario
        columns = ('name', 'scope')

    def get_row_classes(self, row, context):
        result = []
        if row.data.is_ok != 1:
            result.append('fat')
        return result

    def _build_snapshot(self):
        """ Add related information
        We need to fill the _auto_section cache on the related scopes
        """
        super(ScenariosTable, self)._build_snapshot()
        # annotate related elements
        qs = self._snapshot.select_related_versioned('scope')
        if qs:
            version = qs[0]._version
            scopeidlist = []
            for item in qs:
                if item.scope.auto:
                    scopeidlist.append(item.scope.v_id)
            if scopeidlist:
                autosections = installations_models.Scope_Section.objects.filter(scope__in=scopeidlist).get_versionedobjects(version).select_related_versioned('section')
            else:
                autosections = installations_models.Scope_Section.objects.none()
            ssmap = {}
            for item in autosections:
                ssmap[item.scope_id] = item.section
            for item in qs:
                if item.scope.auto:
                    s = ssmap.get(item.scope.v_id)
                    if s:
                        item.scope._auto_section = s
        self._snapshot = qs

class AttentionPointsTable(tables.ModelTable):
    type = tables.Column(
            verbose_name = _('Category'),
        )
    name = tables.Column(
            verbose_name = _('Attention point'),
            link = lambda x: x.data.get_absolute_url(),
        )
    class Meta:
##        model = app_models.AttentionPoint
        columns = ('type', 'name',)

class AllAttentionPointsTable(helpers.SelectRelatedModelTable):
    type = tables.Column(
            verbose_name = _('Category'),
            sortable = True,
        )
    name = tables.Column(
            verbose_name = _('Attention point'),
            link = lambda x: x.data.get_absolute_url(),
            sortable = True,
        )
    measure = tables.Column(
            verbose_name = _('Measure'),
            link = lambda x: x.data.measure.get_absolute_url(),
            sortable = True,
        )
    class Meta:
##        model = app_models.AttentionPoint
        columns = ('type', 'name', 'measure')

class AllAttentionPointsCSVTable(helpers.SelectRelatedModelTable):
    class Meta:
##        model = app_models.AttentionPoint
        columns = ('type', 'name', 'description', 'measure')

class ProtectionLayerMeasuresTable(tables.ModelTable):
    type = tables.Column(
            data = lambda x: x.data.measure.type,
            verbose_name = _('Category'),
            sortable=True,
        )
    name = tables.Column(
            data = lambda x: x.data.measure.name,
            verbose_name = _('Measure'),
            link = lambda x: x.data.measure.get_absolute_url(),
            sortable = True,
        )
    delete = tables.DeleteColumn(
            verbose_name = _('delete'),
    )
    class Meta:
##        model = app_models.ProtectionLayer_Measure
        columns = ('type', 'name', 'delete')

class ProtectionLayersTable(tables.ModelTable):
    name = tables.Column(
            verbose_name = _('Protection layer'),
            link = lambda x: x.data.get_absolute_url(),
            sortable = True,
        )
    class Meta:
##        model = app_models.ProtectionLayer
        columns = ('name',)

class MeasuresTable(tables.ModelTable):
    type = tables.Column(
            verbose_name = _('Category'),
            sortable=True,
        )
    tag = tables.Column(
            verbose_name = _('Tag'),
            sortable = True
        )
    name = tables.Column(
            verbose_name = _('Measure'),
            link = lambda x: x.data.get_absolute_url(),
            sortable = True,
        )
    class Meta:
##        model = app_models.Measure
        columns = ('type', 'tag', 'name',)

class MeasuresCSVTable(tables.ModelTable):
    class Meta:
##        model = app_models.Measure
        columns = ('type', 'tag', 'name', 'description')

class MeasureUsageTable(tables.ModelTable):
    name = tables.Column(
            verbose_name = _('Protection layer'),
            link = lambda x: x.data.get_absolute_url()
        )
    scenario = tables.Column(
            verbose_name = _('Scenario'),
            data = lambda x: x.data.get_treeelements() and x.data.get_treeelements()[0].scenario
        )
    section = tables.Column(
            verbose_name = _('Section or scope'),
            data = lambda x: x.data.get_treeelements() and x.data.get_treeelements()[0].scenario.scope
        )
    class Meta:
##        model = app_models.ProtectionLayer
        columns = ('name',)


class SuggestionListsTable(tables.ModelTable):
    name = tables.Column(
            verbose_name = _('Suggestion list'),
            data = lambda x: u'%s' % x.data,
            link = lambda x: hasattr(x.data, 'url') and x.data.url or x.data.get_absolute_url(),
        )
    class Meta:
##        model = app_models.Suggestionlist
        columns = ('name',)
