from django.conf import settings
from django.utils.translation import ugettext_lazy as _
from utils import tables
import comments.models as app_models
from utils.strings import trim_string

class CommentsTable(tables.ModelTable):
    content_object = tables.Column(
            verbose_name = _('Related object'),
            data = lambda x: x.data.content_object,
            link = lambda x: x.data.content_object.get_absolute_url(),
        )
    comment = tables.Column(
            verbose_name = _('Comment'),
            data = lambda x: trim_string(x.data.comment, 50),
            link = lambda x: x.data.get_absolute_url(),
        )
    user_created = tables.Column(
            verbose_name = _('User'),
            data = lambda x: u'%s %s' % (x.data.user_created.last_name, x.data.user_created.first_name)
        )
    date_created = tables.DateColumn(
            verbose_name = _('Date'),
            format = settings.DATE_OUTPUT_FORMAT
        )
    class Meta:
        model = app_models.Comment
        columns = ('content_object', 'comment', 'user_created', 'date_created')


    def get_row_classes(self, row, context):
        result = []
        if not row.data.response:
            result.append('fat')
        return result

class CommentsCSVTable(tables.ModelTable):
    content_object = tables.Column(
            verbose_name = _('Related object'),
            data = lambda x: x.data.content_object,
        )
    user_created = tables.Column(
            verbose_name = _('User'),
            data = lambda x: u'%s %s' % (x.data.user_created.last_name, x.data.user_created.first_name)
        )
    date_created = tables.DateColumn(
            verbose_name = _('Date'),
            format = settings.DATE_OUTPUT_FORMAT
        )
    user_response = tables.Column(
            verbose_name = _('Respondant'),
            data = lambda x: x.data.user_response and u'%s %s' % (x.data.user_response.last_name, x.data.user_response.first_name) or u''
        )
    class Meta:
        model = app_models.Comment
        columns = ('content_object', 'comment', 'response', 'user_created', 'date_created', 'user_response')


