"""
generic celery tasks
"""

from django.conf import settings
from django.utils.text import capfirst
from django.utils.translation import ugettext_lazy as _
from utils import reports as utils_reports
from utils.versioning.models import Version, WorkVersion

def mail_pdf_for_object(model, pk, user, language=u'en', choices={}):
    object = model.objects.get(pk=pk)
    pdf = object.get_report(user, language=language, choices=choices)
    reference = u'%s: %s' % (capfirst(model._meta.verbose_name), object)
    utils_reports.send_mail(pdf, user, language=language, reference=reference)

def mail_pdf_for_list(listobject, version_id, user, filter, filterdata, language, choices, order_by):
    if not version_id:
        version = WorkVersion
    else:
        version = Version.objects.get(pk=version_id)
    list = listobject()
    pdf = list.get_report(version, user, filter(), filterdata, language, choices, order_by)
    utils_reports.send_mail(pdf, user, language=language, reference=list.get_title())


if settings.USE_CELERY:
    from celery.task import task
    mail_pdf_for_object = task(mail_pdf_for_object)
    mail_pdf_for_list = task(mail_pdf_for_list)
